require(['config'], function() {
	require([
		'kakao.postcode',
		'kakao.maps'
	], function($) {
		pageObj.init();
	});
});

/********************************************************
 --------------------------------------------------------
 - Object 목록								            -
 --------------------------------------------------------
 * const gridColModel = {}	: 화면 Grid Object			*
 * let pageObj = {}			: 화면공통 Object			*
 * let listObj = {}			: 목록화면 Object			*
 * let viewObj = {}			: 상세화면 Object			*
 * let modifyObj = {}		: 수정화면 Object			*
 * let createObj = {}		: 신규화면 Object			*
 *******************************************************/

/*화면 변수*/
const STINFO02010_GRID_ID = '#ITP_STINFO02010_jqGrid';
const STINFO02010_GRID_LIST = '#ITP_STINFO02010_jqGrid_list';
const STINFO02010_GRID_PAGER = '#ITP_STINFO02010_jqGridPager';
const STINFO02010_GRID_EMPTY = '#ITP_STINFO02010_jqGridEmpty';

const STINFO02010_VIEW_GRID_ID = '#ITP_STINFO02010_VIEW_jqGrid';
const STINFO02010_VIEW_GRID_LIST = '#ITP_STINFO02010_VIEW_jqGrid_list';
const STINFO02010_VIEW_GRID_PAGER = '#ITP_STINFO02010_VIEW_jqGridPager';
const STINFO02010_VIEW_GRID_EMPTY = '#ITP_STINFO02010_VIEW_jqGridEmpty';

const STINFO02010_DETAIL_GRID_ID = '#ITP_STINFO02010_DETAIL_jqGrid';
const STINFO02010_DETAIL_GRID_LIST = '#ITP_STINFO02010_DETAIL_jqGrid_list';
const STINFO02010_DETAIL_GRID_PAGER = '#ITP_STINFO02010_DETAIL_jqGridPager';
const STINFO02010_DETAIL_GRID_EMPTY = '#ITP_STINFO02010_DETAIL_jqGridEmpty';

let ITP_FORM_STINFO02010_DETAIL_IS_DUPLICATE = false;
let ITP_FORM_STINFO02010_DETAIL_IS_WRITING = false;

/*API URL*/
let API_DETAIL_GRID_LIST 	= '/api/store/detail-grid-list';	// 목록
let API_DETAIL_INFO 		= '/api/store/info-store';			// 상세
let API_DETAIL_SAVE 		= '/api/store/save-store';			// 저장
let API_INTI_PW				= '/api/store/inti-storePw';		// 패스워드 초기화

/*화면 Grid ColModel*/
const gridColModel = {
	list: [
		{
			index: 'STORE_ID', name: 'storeId',
			label: ITP_MSG_LOCALE.label.storeId, //매장번호
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'STORE_NM', name: 'storeNm',
			label: ITP_MSG_LOCALE.label.storeNm, //매장명
			width: '13', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'BRAND_ID', name: 'brandId',
			label: ITP_MSG_LOCALE.label.brandId, //브랜드ID
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'BRAND_NM', name: 'brandNm',
			label: ITP_MSG_LOCALE.label.brandNm, //브랜드명
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'BSNS_REG_NO', name: 'bsnsRegNo',
			label: ITP_MSG_LOCALE.label.bsnsRegNo, //사업자등록번호
			width: '13', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'STORE_DVSN', name: 'storeDvsn',
			label: ITP_MSG_LOCALE.label.storeDvsn, //매장구분
			width: '15', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'STORE_DVSN_NM', name: 'storeDvsnNm',
			label: ITP_MSG_LOCALE.label.storeDvsn, //매장구분명
			width: '15', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'STORE_ST_NM', name: 'storeStNm',
			label: ITP_MSG_LOCALE.label.stNm, //상태
			width: '6', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'SYS_REG_DTTM', name: 'sysRegDttm',
			label: ITP_MSG_LOCALE.label.sysRegDttm, //최초등록일
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
	],
	detail: [
		{
			index: 'VIEW_CD', name: 'viewCd',
			label: ITP_MSG_LOCALE.label.viewCd,
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'AUTH_NO', name: 'authNo',
			label: ITP_MSG_LOCALE.label.permitCd,
			width: '20', fixed: false, align: 'center',
			sortable: false, editable: false, edittype: 'text',
			editrules: {required: true}
		},
		{
			index: 'AUTH_NM', name: 'authNm',
			label: ITP_MSG_LOCALE.label.permitName,
			width: '30', fixed: false, align: 'center',
			sortable: true, editable: false, edittype: 'text',
			editrules: {required: true}
		},
		{
			index: 'USE_YN_NM', name: 'useYnNm',
			label: ITP_MSG_LOCALE.label.status,
			width: '10', fixed: false, align: 'center',
			sortable: false, editable: false, edittype: 'text'
		},
		{
			index: 'ADD_DT', name: 'addDt',
			label: ITP_MSG_LOCALE.label.regDt,
			width: '10', fixed: false, align: 'center',
			sortable: false, editable: false, edittype: 'text'
		}
	]
};

/*화면공통 Object*/
let pageObj = {
	init: function () {
		this.ui.init();
		this.event.init();
	},
	brandInfo: function() {
		return JSON.parse(sessionStorage.getItem('itp_manage_brand_info'));
	},
	ui: {
		init: function () {
			this.view();
			this.grid();
			this.ready();
		},
		view: function() {
			// 버튼 권한설정
			fn_proc_btn_auth('STINFO02010');

			// 공통코드 표시
			$('select').each(function() {
				if($(this).data('select-code')) {
					fn_make_select(CODE_LIST, $(this).data('select-code'), $(this).attr('id'));
				}
			});
		},
		grid: function() {
			itp_fn_jqgrid_resize(STINFO02010_GRID_ID, STINFO02010_GRID_LIST, 'lg');
			listObj.empty.init();
			itp_fn_fire_window_resize();
		},
		ready: function() {
			listObj.init();
		}
	},
	event: {
		init: function () {
			this.button();
		},
		button: function () {
			// 버튼 클릭 이벤트
			$('button').each(function() {
				var id = $(this).attr('id');
				$(this).on('click', function() {
					switch (id) {
						case 'ITP_BTN_STINFO02010_SRH'				: listObj.button.search();		break;	// 조회 버튼 클릭
						case 'ITP_BTN_STINFO02010_NEWREG'			: listObj.button.create(); 		break;	// 신규등록 버튼
						case 'ITP_BTN_STINFO02010_MODIFY'			: modifyObj.button.modify();	break;	// 수정 버튼
						case 'ITP_BTN_STINFO02010_CANCELLIST'		: createObj.button.cancel(); 	break;	// 취소/목록 버튼
						case 'ITP_BTN_STINFO02010_DELETE'			: 								break;	// 삭제 버튼
						case 'ITP_BTN_STINFO02010_SAVE'				: createObj.button.save(); 		break;	// 저장 버튼
						case 'ITP_FORM_STINFO02010_DETAIL_DUP'		: createObj.button.duplicate();	break;	// 중복체크
						case 'ITP_BTN_STINFO02010_RESET_PW'			: createObj.button.resetPass();	break;	// 상세:비밀번호 초기화
					}
				});
			});

			$('body').on('click', function(e) {
				var gridId = STINFO02010_DETAIL_GRID_ID.replace('#', '');
				var rids = $(STINFO02010_DETAIL_GRID_ID).jqGrid('getDataIDs');
				var last_row_id = rids[rids.length - 1];
				itp_fn_grid_reset_selection(e, last_row_id, gridId, 'STINFO02010_DETAIL');
			});

		}
	},
	switchScreen: function(mode) {
		if(mode == 'LIST') { // 목록
			$('#ITP_BTN_STINFO02010_MODIFY').hide();
			$('#ITP_BTN_STINFO02010_CANCELLIST').hide();
			$('#ITP_BTN_STINFO02010_DELETE').hide();
			$('#ITP_BTN_STINFO02010_SAVE').hide();
			fn_show_btn_auth('#ITP_BTN_STINFO02010_SRH');
			fn_show_btn_auth('#ITP_BTN_STINFO02010_NEWREG');

			$('#ITP_AJAX_STINFO02010_LIST_CONTAINER').show();
			$('#ITP_AJAX_STINFO02010_DETAIL_CONTAINER').hide();
			$('#ITP_AJAX_STINFO02010_VIEW_CONTAINER').hide();
		} else if(mode == 'ADD') { // 등록
			$('#ITP_BTN_STINFO02010_SRH').hide();
			$('#ITP_BTN_STINFO02010_MODIFY').hide();
			$('#ITP_BTN_STINFO02010_NEWREG').hide();
			$('#ITP_BTN_STINFO02010_DELETE').hide();
			$('#ITP_BTN_STINFO02010_RESET_PW').hide();
			fn_show_btn_auth('#ITP_BTN_STINFO02010_CANCELLIST');
			fn_show_btn_auth('#ITP_BTN_STINFO02010_SAVE');

			$('#ITP_AJAX_STINFO02010_LIST_CONTAINER').hide();
			$('#ITP_AJAX_STINFO02010_DETAIL_CONTAINER').show();
			$('#ITP_AJAX_STINFO02010_VIEW_CONTAINER').hide();
			$('#ITP_FORM_STINFO02010_DETAIL_STORE_ID').removeAttr('readonly');
			$('#ITP_FORM_STINFO02010_DETAIL_DUP').removeAttr('disabled');

			$.each($('input, select, checkbox, radio, textarea', '#ITP_FORM_STINFO02010_DETAIL'),function(k) {
				$(this).val('');
			});

			$('#ITP_FORM_STINFO02010_DETAIL_VIEW_CD').val('C');
			$('#ITP_FORM_STINFO02010_DETAIL .fnStoreNm').text('(자동부여)');
			// $('#ITP_FORM_STINFO02010_DETAIL_USER_NM').val('');
			// $('#ITP_FORM_STINFO02010_DETAIL_USER_STAT_CD').val('');
			// $('#ITP_FORM_STINFO02010_DETAIL_STORE_ID').val('');
			// $('#ITP_FORM_STINFO02010_DETAIL_USER_PW').val('');
			// $('#ITP_FORM_STINFO02010_DETAIL_TEL_NO').val('');
			// $('#ITP_FORM_STINFO02010_DETAIL_USER_PW_CONFIRM').val('');
			// $('#ITP_FORM_STINFO02010_DETAIL_EMAIL').val('');
			//
			// $('#ITP_FORM_STINFO02010_DETAIL_SEARCH_AFFL_SHOP_ID').val('');
			// $('#ITP_FORM_STINFO02010_DETAIL_SEARCH_AFFL_SHOP_NM').val('');
			// $('#ITP_FORM_STINFO02010_DETAIL_SEARCH_BRAND_ID option').remove();
			// $('#ITP_FORM_STINFO02010_DETAIL_SEARCH_AFFL_SHOP').show();
			// $('#ITP_FORM_STINFO02010_DETAIL_DELETE_AFFL_SHOP').show();
		} else if(mode == 'MODIFY') { // 수정
			$('#ITP_BTN_STINFO02010_SRH').hide();
			$('#ITP_BTN_STINFO02010_MODIFY').hide();
			$('#ITP_BTN_STINFO02010_NEWREG').hide();
			$('#ITP_BTN_STINFO02010_DELETE').hide();
			fn_show_btn_auth('#ITP_BTN_STINFO02010_CANCELLIST');
			fn_show_btn_auth('#ITP_BTN_STINFO02010_SAVE');
			fn_show_btn_auth('#ITP_BTN_STINFO02010_RESET_PW');

			$('#ITP_AJAX_STINFO02010_LIST_CONTAINER').hide();
			$('#ITP_AJAX_STINFO02010_DETAIL_CONTAINER').show();
			$('#ITP_AJAX_STINFO02010_VIEW_CONTAINER').hide();
			$('#ITP_FORM_STINFO02010_DETAIL_STORE_ID').attr('readonly', true);
			$('#ITP_FORM_STINFO02010_DETAIL_DUP').attr('disabled', true);
			$('#ITP_FORM_STINFO02010_DETAIL_SEARCH_AFFL_SHOP_NM').attr('readonly', true);

			$('#ITP_FORM_STINFO02010_DETAIL_SEARCH_AFFL_SHOP').hide();
			$('#ITP_FORM_STINFO02010_DETAIL_DELETE_AFFL_SHOP').hide();
		} else if(mode == 'VIEW') { // 보기
			$('#ITP_BTN_STINFO02010_SRH').hide();
			$('#ITP_BTN_STINFO02010_NEWREG').hide();
			$('#ITP_BTN_STINFO02010_DELETE').hide();
			$('#ITP_BTN_STINFO02010_SAVE').hide();
			fn_show_btn_auth('#ITP_BTN_STINFO02010_MODIFY');
			fn_show_btn_auth('#ITP_BTN_STINFO02010_CANCELLIST');

			$('#ITP_AJAX_STINFO02010_LIST_CONTAINER').hide();
			$('#ITP_AJAX_STINFO02010_DETAIL_CONTAINER').hide();
			$('#ITP_AJAX_STINFO02010_VIEW_CONTAINER').show();
		}
	}
};

/*목록화면 Object*/
let listObj = {
	init: function () {
		this.grid.init();
	},
	itp_STINFO02010_search: false,
	button: {
		search: function() {
			listObj.itp_STINFO02010_search = true;
			let param = $('#ITP_FORM_STINFO02010_SEARCH').serializeObject();
			param.gridSize = $.jgrid.defaults.rowNum;
			param.gridPage = $.jgrid.defaults.page;
			$(STINFO02010_GRID_ID).setGridParam({'postData': JSON.stringify(param)}).trigger('reloadGrid');
		},
		create: function() {
			pageObj.switchScreen('ADD');
			itp_fn_form_clear_validate(null, '#ITP_FORM_STINFO02010_DETAIL');
			createObj.init();
		}
	},
	empty: {
		init: function() {
			var _this = this;
			this.push();
			$(STINFO02010_GRID_EMPTY).on('click', function() {
				_this.back();
				_this.itp_STINFO02010_param.gridSize = $.jgrid.defaults.rowNum;
				$(STINFO02010_GRID_ID).setGridParam({'postData': JSON.stringify(_this.itp_STINFO02010_param)}).trigger('reloadGrid');
			});
		},
		itp_STINFO02010_param: {},
		push: function() {
			let param = $('#ITP_FORM_STINFO02010_SEARCH').serializeObject();
			listObj.itp_STINFO02010_param = param;
		},
		back: function() {
			$('#ITP_FORM_STINFO02010_SERVICE_ST_DT').val(this.itp_STINFO02010_param.serviceStDt);
			$('#ITP_FORM_STINFO02010_SEARCH_REG_DT').val(this.itp_STINFO02010_param.sregDt);
			$('#ITP_FORM_STINFO02010_SEARCH_OPEN_DT').val(this.itp_STINFO02010_param.sopenDt);
			$('#ITP_FORM_STINFO02010_SEARCH_STORE_DVSN').val(this.itp_STINFO02010_param.sstoreDvsn);
			$('#ITP_FORM_STINFO02010_SEARCH_STORE_ST_CD').val(this.itp_STINFO02010_param.sstoreStCd);
			$('#ITP_FORM_STINFO02010_SEARCH_LOAN_DVSN').val(this.itp_STINFO02010_param.sdvsn);
			$('#ITP_FORM_STINFO02010_SEARCH_STORE_NM').val(this.itp_STINFO02010_param.sstoreMm);
		}
	},
	grid: {
		init: function () {
			// 데이터 없을때
			listObj.empty.push();
			this.search();
		},
		colModel: gridColModel.list,
		search: function() {
			pageObj.switchScreen('LIST');
			this.unload();
			this.load();
		},
		load: function() {
			let param = $('#ITP_FORM_STINFO02010_SEARCH').serializeObject();
			param.gridSize = $.jgrid.defaults.rowNum;
			param.sbrandId = pageObj.brandInfo.brandId;
			// param.sbrandId = sessionStorage.getItem('itp_brand_id') !== null ? sessionStorage.getItem('itp_brand_id') : 'BRD221000001';

			var option = {
				gridId: STINFO02010_GRID_ID,
				colModel: gridColModel.list,
				param: JSON.stringify(param),
				url: DOMAIN + API_DETAIL_GRID_LIST,
				pager: STINFO02010_GRID_PAGER,
				onCellSelect: function(rowId, cellIdx, cellValue) {
					var cm = $(this).jqGrid('getGridParam', 'colModel');
					var colNm = cm[cellIdx].name;
					if (colNm == 'storeNm') {
						const selectVal = $(this).jqGrid('getCell', rowId, 'storeId');
						const key = {brandId:pageObj.brandInfo.brandId, storeId: selectVal, viewCd: 'R'};
						var param = $.param(key);
						viewObj.init(param);
					}
				},
				loadComplete: function(data) {
					console.log(data);
					itp_fn_grid_load_complete(data, STINFO02010_GRID_ID, true, 'number', 'STINFO02010', listObj.itp_STINFO02010_search, listObj.empty, true, data.gridRecords, true);
					var ids = $(STINFO02010_GRID_ID).getDataIDs();
					$.each(ids, function(idx, rowId) {
						$(STINFO02010_GRID_ID).jqGrid('setCell', rowId, 'storeNm', '', ITP_GRID_COL_STYLE.link);
					});
				},
				onPaging: function(action) {
					itp_fn_grid_paging(STINFO02010_GRID_ID, action, param);
				}
			};
			itp_fn_grid_make_remote(option);
		},
		clearData : function() {
			$(STINFO02010_GRID_ID).jqGrid('clearGridData', true);
			$(STINFO02010_GRID_LIST).find('.ui-jqgrid-bdiv').css('min-height', '100px');
			$(STINFO02010_GRID_EMPTY).html(ITP_MSG_LOCALE.message.grid.noData);
			$(STINFO02010_GRID_EMPTY).show();
		},
		unload : function() {
			$.jgrid.gridUnload(STINFO02010_GRID_ID);
		}
	}
};

/*상세화면 Object*/
let viewObj = {
	init: function (param) {
		this.load(param);
	},
	load: function(param) {
		fn_ajax_call(API_DETAIL_INFO, param, this.callback, 'GET');
	},
	callback: function (result) {
		// console.log(result);
		pageObj.switchScreen('VIEW');
		$('#ITP_FORM_STINFO02010_VIEW #ITP_FORM_STINFO02010_VIEW_STORE_ID').val(result.storeId);
		$('#ITP_FORM_STINFO02010_VIEW .fnBrandNm').text(result.brandNm);
		$('#ITP_FORM_STINFO02010_VIEW .fnStCd').text(result.storeStNm);
		$('#ITP_FORM_STINFO02010_VIEW .fnStoreId').text(result.storeId);
		$('#ITP_FORM_STINFO02010_VIEW .fnStoreDvsn').text(result.storeDvsnNm);
		$('#ITP_FORM_STINFO02010_VIEW .fnStoreNm').text(result.storeNm);
		$('#ITP_FORM_STINFO02010_VIEW .fnBsnsCndt').text(result.bsnsCndt);
		$('#ITP_FORM_STINFO02010_VIEW .fnBsnsRegNo').text(result.bsnsRegNo);
		$('#ITP_FORM_STINFO02010_VIEW .fnCtgrBsns').text(result.ctgrBsns);
		$('#ITP_FORM_STINFO02010_VIEW .fnCorpRegNo').text(result.corpRegNo);
		$('#ITP_FORM_STINFO02010_VIEW .fnTelNo').text(result.telNo);
		$('#ITP_FORM_STINFO02010_VIEW .fnOwnerNm').text(result.ownerNm);
		$('#ITP_FORM_STINFO02010_VIEW .fnFaxNo').text(result.faxNo);
		$('#ITP_FORM_STINFO02010_VIEW .fnMblNo').text(result.telNo);
		$('#ITP_FORM_STINFO02010_VIEW .fnEmalAddr').text(result.emalAddr);
		$('#ITP_FORM_STINFO02010_VIEW .fnAreaCd').text(result.areaNm);
		$('#ITP_FORM_STINFO02010_VIEW .fnFromDt').text(result.openDt);
		$('#ITP_FORM_STINFO02010_VIEW .fnZipNo').text(result.zipNo);
		$('#ITP_FORM_STINFO02010_VIEW .fnLoadAddr').text(result.addr1);
		$('#ITP_FORM_STINFO02010_VIEW .fnDtlAddr').text(result.addr2);

		var cmpyAdres = result.addr1/* + ' ' + result.addr*/;
		kakaoMap.init('ITP_FORM_STINFO02010_VIEW_MAP', cmpyAdres);

		$('#ITP_FORM_STINFO02010_VIEW .fnBrandAcctInfo').text(result.brandAcctNo);
		$('#ITP_FORM_STINFO02010_VIEW .fnLoanDvsn').text(result.loanDvsnNm);
		$('#ITP_FORM_STINFO02010_VIEW .fnCredtLimitAmt').text(result.limitAmt);
		$('#ITP_FORM_STINFO02010_VIEW .fnTmpRcvAcct').text(result.storeAcctNo);
		$('#ITP_FORM_STINFO02010_VIEW .fnRemainLimitAmt').text(result.limitAmt);
		$('#ITP_FORM_STINFO02010_VIEW .fnRegDt').text(result.sysRegDttm);
		$('#ITP_FORM_STINFO02010_VIEW .fnCloseDt').text(result.closeDt);
	}
};

/*수정화면 Object*/
let modifyObj = {
	init: function () {
	},
	button: {
		modify: function (param) {
			itp_fn_form_clear_validate(null, '#ITP_FORM_STINFO02010_DETAIL');
			const selectVal = $('#ITP_FORM_STINFO02010_VIEW_STORE_ID').val();
			const key = {brandId:pageObj.brandInfo.brandId, storeId: selectVal, viewCd: 'R'};
			var param = $.param(key);
			modifyObj.load(param);
		}
	},
	load: function(param) {
		fn_ajax_call(API_DETAIL_INFO, param, this.callback, 'GET');
	},
	callback: function (result) {
		console.log(result);
		pageObj.switchScreen('MODIFY');

		fn_make_select(CODE_LIST, 'STORE_ST_CD', 'ITP_FORM_STINFO02010_DETAIL_STORE_ST_CD');
		fn_make_select(CODE_LIST, 'AREA_CD', 'ITP_FORM_STINFO02010_DETAIL_AREA_CD');
		fn_make_select(CODE_LIST, 'STORE_DVSN', 'ITP_FORM_STINFO02010_DETAIL_STORE_DVSN');
		fn_make_select(CODE_LIST, 'LOAN_DVSN', 'ITP_FORM_STINFO02010_DETAIL_LOAN_DVSN');

		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_VIEW_CD').val('U');
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_STORE_ID').val(result.storeId);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_BRAND_ID').val(pageObj.brandInfo.brandId);
		$('#ITP_FORM_STINFO02010_DETAIL .fnBrandNm').text(result.brandNm);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_STORE_ST_CD').val(result.storeStCd);
		$('#ITP_FORM_STINFO02010_DETAIL .fnStoreNm').text(result.storeId);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_STORE_DVSN').val(result.storeDvsn);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_STORE_NM').val(result.storeNm);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_BSNS_CNDT').val(result.bsnsCndt);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_BSNS_REG_NO').val(result.bsnsRegNo);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_CTGR_BSNS').val(result.ctgrBsns);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_CORP_REG_NO').val(result.bsnsRegNo);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_TEL_NO').val(result.telNo);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_OWNER_NM').val(result.ownerNm);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_FAX_NO').val(result.faxNo);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_MBL_NO').val(result.telNo);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_EMAL_ADDR').val(result.emalAddr);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_AREA_CD').val(result.areaCd);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_FROM_DT').val(result.openDt);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_ZIP_NO').val(result.zipNo);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_LOAD_ADDR').val(result.addr1);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_DTL_ADDR').val(result.addr2);
		$('#ITP_FORM_STINFO02010_DETAIL .fbBrandAcctInfo').text(result.brandAcctNo);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_LOAN_DVSN').val(result.loanDvsn);
		$('#ITP_FORM_STINFO02010_DETAIL #ITP_FORM_STINFO02010_DETAIL_CREDT_LIMIT_AMT').val(result.limitAmt);

		var cmpyAdres = result.addr1/* + ' ' + result.addr*/;
		kakaoMap.init('ITP_FORM_STINFO02010_DETAIL_MAP', cmpyAdres);
	}
};

/*신규화면 Object*/
let createObj = {
	init: function () {
		$('#ITP_FORM_STINFO02010_DETAIL_BRAND_ID').val(pageObj.brandInfo.brandId);
		kakaoMap.init('ITP_FORM_STINFO02010_DETAIL_MAP', '');
	},
	button: {
		cancel: function() {
			listObj.grid.search();
		},
		save: function() {
			const formId = '#ITP_FORM_STINFO02010_DETAIL';
			itp_fn_form_clear_validate(null, formId);
			var vali_userId = itp_fn_form_validate(formId, formId + '_USER_ID', ['empty'], undefined);
			var vali_userStatCd = itp_fn_form_validate(formId, formId + '_USER_STAT_CD', ['empty'], undefined);
			var vali_userNm = itp_fn_form_validate(formId, formId + '_USER_NM', ['empty'], undefined);
			var vali_telNo = itp_fn_form_validate(formId, formId + '_TEL_NO', ['empty'], undefined);
			var vali_email = itp_fn_form_validate(formId, formId + '_EMAIL', ['empty'], undefined);
			var vali_userPw = true;
			var vali_userPwConfirm = true;
			if (vali_userId && vali_userStatCd && vali_userNm && vali_userPw && vali_userPwConfirm && vali_telNo && vali_email) {
				if (ITP_FORM_STINFO02010_DETAIL_IS_DUPLICATE) {
					itp_fn_modal_duplicate(ITP_MSG_LOCALE.label.userId, formId + '_USER_ID');
				} else {
					let gridInsertData = [];
					let gridUpdateData = [];
					let gridDeleteData = [];
					const rowData = $(STINFO02010_DETAIL_GRID_ID).getRowData();
					const keyValue = $(formId + '_USER_ID').val();
					$.each(rowData, function(key, value) {
						if (value.viewCd != 'R') {
							value.userId = keyValue;
							if (value.viewCd == 'C') {
								gridInsertData.push(value);
							} else if (value.viewCd == 'U') {
								gridUpdateData.push(value);
							} else if (value.viewCd == 'D') {
								gridDeleteData.push(value);
							}
						}
					});
					let param = $(formId).serializeObject();
					param.gridInsertData = gridInsertData;
					param.gridUpdateData = gridUpdateData;
					param.gridDeleteData = gridDeleteData;
					//console.log(JSON.stringify(param));
					var searhFn = function() {
						ITP_FORM_STINFO02010_DETAIL_IS_WRITING = false;
						listObj.grid.search();
					};
					fn_ajax_call(API_DETAIL_SAVE, JSON.stringify(param), searhFn, 'POST');
				}
			}
		},
		resetPass: function() {
			var resetPwFn = {
				callBack: function(args) {
					const key = {'storeId':  $('#ITP_FORM_STINFO02010_DETAIL_STORE_ID').val()};
					const param = $.param(key);
					fn_ajax_call(API_INTI_PW, param, undefined, 'GET');
				}
			};
			itp_fn_modal_confirm(ITP_MSG_LOCALE.message.ajax.askResetUserPw, resetPwFn, null);
		}
	}
};

let kakaoMap = {
	init: function(id, locate) {
		this.load(id, locate);
	},
	geocoder: null,
	schDetailAddrFromCoords: function(coords, callback) {
		// 좌표로 법정동 상세 주소 정보를 요청합니다
		if(this.geocoder) {
			this.geocoder.coord2Address(coords.getLng(), coords.getLat(), callback);
		}
	},
	getMap: function(id) {
		var mapContainer = document.getElementById(id), // 지도를 표시할 div
			mapOption = {
				center: new kakao.maps.LatLng(37.56684, 126.97865), // 지도의 중심좌표
				level: 3, // 지도의 확대 레벨
				mapTypeId : kakao.maps.MapTypeId.ROADMAP // 지도종류
			};

		// 지도를 생성한다
		var map = new kakao.maps.Map(mapContainer, mapOption);

		// 마우스 휠과 모바일 터치를 이용한 지도 확대, 축소를 막는다
		map.setZoomable(false);

		// 지도에 확대 축소 컨트롤을 생성한다
		//var zoomControl = new kakao.maps.ZoomControl();

		// 지도의 우측에 확대 축소 컨트롤을 추가한다
		//map.addControl(zoomControl, kakao.maps.ControlPosition.RIGHT);

		return map;
	},
	marker: function(map, coords) {
		// 지도에 마커를 생성하고 표시한다
		marker = new kakao.maps.Marker({
			position: coords, // 마커의 좌표
			map: map // 마커를 표시할 지도 객체
		});
	},
	load: function(id, locate) {
		var _this = this;
		kakao.maps.load(function() {
			var map = _this.getMap(id);
			// 주소-좌표 변환 객체를 생성합니다
			_this.geocoder = new kakao.maps.services.Geocoder();
			if( !locate || locate.length == 0 ) {
				// 지도에 마커를 생성하고 표시한다
				_this.marker(map, new kakao.maps.LatLng(37.56684, 126.97865));
			} else {
				// 주소로 좌표를 검색합니다
				_this.geocoder.addressSearch(locate, function(result, status) {
					// 정상적으로 검색이 완료됐으면
					if (status === kakao.maps.services.Status.OK) {

						var coords = new kakao.maps.LatLng(result[0].y, result[0].x);
						if(id === 'ITP_FORM_STINFO02010_DETAIL_MAP') {
							document.getElementById('ITP_FORM_STINFO02010_DETAIL_LAT').value = result[0].y;
							document.getElementById('ITP_FORM_STINFO02010_DETAIL_LNG').value = result[0].x;
						}

						// 결과값으로 받은 위치를 마커로 표시합니다
						_this.marker(map, coords);

						// 지도의 중심을 결과값으로 받은 위치로 이동시킵니다
						map.setCenter(coords);
					} else {
						_this.marker(map, new kakao.maps.LatLng(37.56684, 126.97865));
					}
				});
			}

			if(id === 'ITP_FORM_STINFO02010_DETAIL_MAP') {
				_this.listener.drag(map);
			}
		});
	},
	listener: {
		drag: function(map) {
			var _this = this;
			// 지도 드래깅 이벤트를 등록한다 (드래그 시작 : dragstart, 드래그 종료 : dragend)
			kakao.maps.event.addListener(map, 'drag', function () {
				kakaoMap.schDetailAddrFromCoords(map.getCenter(), function(result, status) {
					if (status === kakao.maps.services.Status.OK) {

						document.getElementById('ITP_FORM_STINFO02010_DETAIL_LOTS_ADDRESS').value = result[0].address.address_name ;
						document.getElementById('ITP_FORM_STINFO02010_DETAIL_ADRES').value = !!result[0].road_address ? result[0].road_address.address_name : result[0].address.address_name ;
						document.getElementById('ITP_FORM_STINFO02010_DETAIL_STREET_ADDRESS').value = !!result[0].road_address ? result[0].road_address.address_name : $('#ITP_FORM_STINFO02010_DETAIL_STREET_ADDRESS').val();
						document.getElementById('ITP_FORM_STINFO02010_DETAIL_ZIPNO').value = !!result[0].road_address ? result[0].road_address.zone_no : $('#ITP_FORM_STINFO02010_DETAIL_CMPY_ZIPNO').val() ;
						document.getElementById('ITP_FORM_STINFO02010_DETAIL_LAT').value = map.getCenter().getLat();
						document.getElementById('ITP_FORM_STINFO02010_DETAIL_LNG').value = map.getCenter().getLng();

						// 마커를 클릭한 위치에 표시합니다
						marker.setPosition(map.getCenter());
						marker.setMap(map);
					}
				});
				/* 	var message = '지도를 드래그 하고 있습니다. 지도의 중심 좌표는 ' + map.getCenter().toString() +' 입니다.';
                console.log(message); */
			});
		}
	}
};
